@@ -1,11 +1,11 @@
 #' Recast: melt and cast in a single step
-#' 
-#' This conveniently wraps melting and casting a data frame into
-#' a single step. 
+#'
+#' This conveniently wraps melting and (d)casting a data frame into
+#' a single step.
 #'
 #' @param data data set to melt
-#' @param formula casting formula, see \link{cast} for specifics
-#' @param ... other arguments passed to \link{cast}
+#' @param formula casting formula, see \code{\link{dcast}} for specifics
+#' @param ... other arguments passed to \code{\link{dcast}}
 #' @param id.var identifying variables. If blank, will use all non
 #'    measure.var variables
 #' @param measure.var measured variables. If blank, will use all non
@@ -19,7 +19,7 @@ recast <- function(data, formula, ..., id.var, measure.var) {
   if (any(c("id.vars", "measure.vars") %in% names(match.call()))) {
     stop("Use var, not vars\n")
   }
-  
+
   molten <- melt(data, id.var, measure.var)
-  cast(molten, formula, ...)
+  dcast(molten, formula, ...)
 }
